Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(424)

Unified Diff: content/browser/renderer_host/accelerated_surface_container_mac.h

Issue 9194005: gpu: reference target surfaces through a globally unique surface id. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: fix more tests Created 8 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/renderer_host/accelerated_surface_container_mac.h
diff --git a/content/browser/renderer_host/accelerated_surface_container_mac.h b/content/browser/renderer_host/accelerated_surface_container_mac.h
index 1bbf7308888f58e3772828188a90068af523c54c..2e172101fadfba4972d1da4b0ce1e8fbdc0bec60 100644
--- a/content/browser/renderer_host/accelerated_surface_container_mac.h
+++ b/content/browser/renderer_host/accelerated_surface_container_mac.h
@@ -82,8 +82,8 @@ class AcceleratedSurfaceContainerMac {
bool ShouldBeVisible() const;
// Notifies the the container that its surface was painted to.
- void set_was_painted_to(uint64 surface_id);
- void set_was_painted_to(uint64 surface_id,
+ void set_was_painted_to(uint64 surface_handle);
+ void set_was_painted_to(uint64 surface_handle,
const gfx::Rect& update_rect);
// Notifies the container that its surface is invalid.
@@ -92,7 +92,7 @@ class AcceleratedSurfaceContainerMac {
// Enqueue our texture for later deletion.
void EnqueueTextureForDeletion();
- void set_was_painted_to_common(uint64 surface_id);
+ void set_was_painted_to_common(uint64 surface_handle);
// The manager of this accelerated surface container.
AcceleratedSurfaceContainerManagerMac* manager_;
@@ -106,8 +106,8 @@ class AcceleratedSurfaceContainerMac {
// IOSurfaceRef type when building on 10.5.
base::mac::ScopedCFTypeRef<CFTypeRef> surface_;
- // The id of |surface_|, or 0 if |surface_| is NULL.
- uint64 surface_id_;
+ // The handle of |surface_|, or 0 if |surface_| is NULL.
+ uint64 surface_handle_;
// The width and height of the io surface. During resizing, this is different
// from |width_| and |height_|.

Powered by Google App Engine
This is Rietveld 408576698